@@ -73,9 +73,10 @@ class ModelResults:
         vocab = vectorizer.get_feature_names()
         vector_df = pd.DataFrame(vectors, columns=vocab, index=X.index)
 
+        if X.shape[0] < 20:
+            return "Too few examples to categorize."
+
         if not num_topics:
-            if X.shape[0] < 20:
-                return "Too few examples to categorize."
 
             # In case 1, add 1 to get at least 2
             # The rest are based on eyeballing numbers
@@ -119,7 +120,7 @@ class ModelResults:
                 )
 
                 cm = CoherenceModel(
-                    model=model, texts=texts, dictionary=dictionary, coherence="c_v"
+                    model=model, texts=texts, dictionary=dictionary, coherence="u_mass"
                 )
 
                 coherence_scores.append(round(cm.get_coherence(), 5))
@@ -305,7 +306,7 @@ class ModelResults:
             Number of text examples to include per group
         num_times_min: int
             Minimum number of times word/phrase must appear in texts
-        min_n_gram: int
+        min_ngram: int
 
         Returns
         --------
@@ -313,6 +314,12 @@ class ModelResults:
             Has groups, top words, and counts
 
         """
+        # Fix for when column name is the same as an ngram column name
+        X["group_column"] = X[group_col_name]
+
+        # Remove all other unneeded columns
+        X = X[[text_col_name, "group_column"]]
+
         all_stop_words = (
             set(ENGLISH_STOP_WORDS)
             | set(["-PRON-"])
@@ -330,15 +337,16 @@ class ModelResults:
         group_plus_vectors = pd.concat([vectors_df, X.reset_index(drop=False)], axis=1)
 
         count_words = pd.DataFrame(
-            group_plus_vectors.groupby(group_col_name).count()["index"]
+            group_plus_vectors.groupby("group_column").count()["index"]
         )
-        count_words.columns = ["count"]
+        # Fix for when "count" is an ngram column
+        count_words.columns = ["count_ngrams"]
 
         group_plus_vectors = group_plus_vectors.merge(
-            count_words, on=group_col_name, how="left"
+            count_words, on="group_column", how="left"
         )
 
-        group_plus_vectors["count"].fillna(0, inplace=True)
+        group_plus_vectors["count_ngrams"].fillna(0, inplace=True)
 
         sums_by_col = (
             group_plus_vectors[
@@ -346,13 +354,13 @@ class ModelResults:
                     ~group_plus_vectors.columns.isin([text_col_name, "index",])
                 ]
             ]
-            .groupby(group_col_name)
+            .groupby("group_column")
             .sum()
         )
 
-        sums_by_col.sort_values(by="count", ascending=False, inplace=True)
+        sums_by_col.sort_values(by="count_ngrams", ascending=False, inplace=True)
 
-        sums_by_col.drop("count", axis=1, inplace=True)
+        sums_by_col.drop("count_ngrams", axis=1, inplace=True)
 
         array_sums = np.array(sums_by_col)
         sums_values_descending = -np.sort(-array_sums, axis=1)
